SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveVcc] (
	@VCC VARCHAR(50) = NULL, 
	@ID VARCHAR(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360,
	@ChangedCognitiveEngine BIT = 0,
	@UseRasaApi				BIT = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @IsMigrating BIT = 0
	IF(@ChangedCognitiveEngine IS NOT NULL AND @ChangedCognitiveEngine = 1)
	   SET @IsMigrating = 1
	   
	IF(EXISTS(SELECT [ID] FROM [dbo].[VCC] (NOLOCK) WHERE [VCC] = @VCC))
	BEGIN
			UPDATE [VCC]
				SET [Description] = @Description,
					[Type] = @Type,
					[Country] = @Country,
					[TranscriptionDefaultLanguage] = @TranscriptionDefaultLanguage,
					[CognitiveEngine] = @CognitiveEngine,
					[Language] = @Language,
					[TimeZone] = @TimeZone,
					[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
					[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
					[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
					[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
					[IsMigrating] = IIF(@IsMigrating = 1,1,0),
					[DeleteDataDays] = @DeleteDataDays,
					[TimeStamp] = GETUTCDATE()
				WHERE [VCC] = @VCC
					AND [ID] = @ID
		

		-- insertamos los permisos que faltan 

			DECLARE @RowCount INT,
					@RowCountRoutePermision INT

			DECLARE @ROLE_PERMISSIONS TABLE(
					[RoleId]  VARCHAR(50),
					[GroupId] VARCHAR(200)
				)			 
		
			INSERT INTO @ROLE_PERMISSIONS 
				SELECT 					
				RPT.RoleId, 
				RPT.GroupId
				FROM dbo.RolePermission RPT
				INNER JOIN dbo.RolePermissionsGroup RPG ON RPG.GroupId = RPT.GroupId AND RPG.VCC = RPT.VCC
				WHERE RPT.VCC = 'system'
					AND NOT EXISTS(
									SELECT * 
									FROM dbo.RolePermission RP 
									WHERE RP.GroupId = RPT.GroupId 
										AND RP.VCC = @VCC
											)

			DECLARE @ROUTE_PERMISSIONS TABLE(
				 [Id]      VARCHAR(50),
				 [Route]   VARCHAR(250),
				 [Level]   VARCHAR(50),
				 [GroupId] VARCHAR(200)
				)

			INSERT INTO @ROUTE_PERMISSIONS
						SELECT 
						NEWID(),  
						RPT.Route, 
						RPT.Level,
						RPG.GroupId
						FROM dbo.RoutePermission RPT
						INNER JOIN dbo.RolePermissionsGroup RPG ON RPG.GroupId = RPT.GroupId AND RPG.VCC = RPT.VCC
						WHERE RPT.VCC = 'system'
						AND NOT EXISTS(
										SELECT * 
										FROM dbo.RoutePermission RP 
										WHERE RP.GroupId = RPT.GroupId 
											AND RP.VCC = @VCC
										)


			SELECT @RowCount = COUNT(*) FROM @ROLE_PERMISSIONS

			IF @RowCount > 0
			BEGIN

			INSERT INTO [dbo].[RolePermission](
						[VCC],
						[RoleId],
						[GroupId],
						[TimeStamp]
						)
						SELECT	
						@VCC, 
						[RoleId],
						[GroupId],
						GETUTCDATE()
						FROM @ROLE_PERMISSIONS
			END		
		 
			SELECT @RowCountRoutePermision = COUNT(*)  FROM @ROUTE_PERMISSIONS

			IF @RowCountRoutePermision > 0
			BEGIN
				INSERT INTO dbo.RoutePermission (
							VCC,
							ID,
							GroupId,
							Route,
							Level,
							TimeStamp
							)
							SELECT
							@VCC,
							[Id],
							[GroupId],
							[Route],  
							[Level],  
							GETUTCDATE()
							FROM @ROUTE_PERMISSIONS						
			END
   END
   ELSE
   BEGIN
   			   EXEC [dbo].[CreateVcc] @VCC,
									  @ID, 
									  @Description, 
									  @Type, 
									  @TranscriptionDefaultLanguage,
									  @CognitiveEngine, 
									  @Country, 
									  @Language, 
									  @TimeZone, 
									  @CreatedDate,  
									  @CreatedByUserId, 
									  @LastModifiedDate, 
									  @LastModifiedByUserId, 
									  @DeleteDataDays,
									  @UseRasaApi
   END

		
		
	--SI HA CAMBIADO LOS NLUS ACTUALIZAR EL ESTADO DE LOS MODELOS A NO DISPONIBLE
	IF(@IsMigrating = 1)
	BEGIN 
	  EXEC SaveCognitiveEngineMigrateStatus @VCC,'*','*',0,'NOT_AVAILABLE'
	END



    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
